==> jc-1.4.0.tar.gz: gnu/java/net/protocol/jar/Connection__24JarFileCache.h <==
// public class gnu.java.net.protocol.jar.Connection$JarFileCache

// class file dependencies
// @dep_class bcba583c3ddbc290 gnu_java_net_protocol_jar_Connection__24JarFileCache
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_
#define _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object;

typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct {
	struct _jc_java_util_Hashtable$object	*cache;
	jint	READBUFSIZE;
};
extern _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object *);

// Static methods
extern void _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_util_jar_JarFile$object *_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$get$9195583779421c81(_jc_env *, struct _jc_java_net_URL$object *);

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods {
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods	gnu_java_net_protocol_jar_Connection__24JarFileCache;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs {
    _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs	gnu_java_net_protocol_jar_Connection__24JarFileCache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs	gnu_java_net_protocol_jar_Connection__24JarFileCache;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object {
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Connection__24JarFileCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/jar/Connection__24JarFileCache.h <==
// public class gnu.java.net.protocol.jar.Connection$JarFileCache

// class file dependencies
// @dep_class bcba583c3ddbc290 gnu_java_net_protocol_jar_Connection__24JarFileCache
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_
#define _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object;

typedef struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct {
	struct _jc_java_util_Hashtable$object	*cache;
	jint	READBUFSIZE;
};
extern _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$fields_struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_util_jar_JarFile$object *_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$method$get$9195583779421c81(_jc_env *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods {
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vmethods	gnu_java_net_protocol_jar_Connection__24JarFileCache;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs {
    _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_refs	gnu_java_net_protocol_jar_Connection__24JarFileCache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$sub_nonrefs	gnu_java_net_protocol_jar_Connection__24JarFileCache;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$object {
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$vtype _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Connection__24JarFileCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Connection__24JarFileCache$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Connection__24JarFileCache_H_ */
